=== modified file 'NEWS'
--- NEWS	2010-04-26 23:36:26 +0000
+++ NEWS	2010-04-27 07:52:08 +0000
@@ -43,6 +43,10 @@
 * Reduce peak memory by one copy of compressed text.
   (John Arbash Meinel, #566940)
 
+* Show the filenames when a file rename fails so that the error will be
+  more comprehensible.
+  (Martin Pool, #491763)
+
 Improvements
 ************
 

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2010-04-24 09:08:27 +0000
+++ bzrlib/osutils.py	2010-04-27 07:52:08 +0000
@@ -362,6 +362,14 @@
     return _win32_fixdrive(tempfile.mkdtemp(*args, **kwargs).replace('\\', '/'))
 
 
+def _add_rename_error_details(e, old, new):
+    new_e = OSError(e.errno, "failed to rename %s to %s: %s"
+        % (old, new, e.strerror))
+    new_e.filename = old
+    new_e.to_filename = new
+    return new_e
+
+
 def _win32_rename(old, new):
     """We expect to be able to atomically replace 'new' with old.
 
@@ -369,7 +377,7 @@
     and then deleted.
     """
     try:
-        fancy_rename(old, new, rename_func=os.rename, unlink_func=os.unlink)
+        fancy_rename(old, new, rename_func=_wrapped_rename, unlink_func=os.unlink)
     except OSError, e:
         if e.errno in (errno.EPERM, errno.EACCES, errno.EBUSY, errno.EINVAL):
             # If we try to rename a non-existant file onto cwd, we get
@@ -380,6 +388,16 @@
         raise
 
 
+def _wrapped_rename(old, new):
+    """Rename a file or directory"""
+    try:
+        os.rename(old, new)
+    except (IOError, OSError), e:
+        # this is eventually called by all rename-like functions, so should 
+        # catch all of them
+        raise _add_rename_error_details(e, old, new)
+
+
 def _mac_getcwd():
     return unicodedata.normalize('NFC', os.getcwdu())
 
@@ -390,8 +408,8 @@
 realpath = _posix_realpath
 pathjoin = os.path.join
 normpath = os.path.normpath
+rename = _wrapped_rename # overridden below on win32
 getcwd = os.getcwdu
-rename = os.rename
 dirname = os.path.dirname
 basename = os.path.basename
 split = os.path.split

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2010-04-24 13:48:58 +0000
+++ bzrlib/tests/test_osutils.py	2010-04-27 07:52:08 +0000
@@ -184,6 +184,13 @@
         shape = sorted(os.listdir('.'))
         self.assertEquals(['A', 'B'], shape)
 
+    def test_rename_error(self):
+        # We wrap os.rename to make it give an error including the filenames
+        # https://bugs.launchpad.net/bzr/+bug/491763
+        err = self.assertRaises(OSError, osutils.rename,
+            'nonexistent', 'target')
+        self.assertContainsString(str(err), 'nonexistent')
+
 
 class TestRandChars(tests.TestCase):
 

